# Formica

Tool tự động hóa công việc

## Requirements

- Python 3.12 (bắt buộc)
- [uv](https://github.com/astral-sh/uv) (nên dùng, nhưng ko bắt buộc)
## Cài đặt

### **Cách 1**: dùng `uv`

#### 1. Cài uv

```bash
curl -LsSf https://astral.sh/uv/install.sh | sh
```

#### 2. Sync môi trường
